==> ssp-center-api-0.9.88-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteAccountChangeService.java <==
/**
 * Project Name:ssp-center-api
 * File Name:RemoteAccountChangeService.java
 * Package Name:cn.com.duiba.tuia.ssp.center.api.remote
 * Date:2017年5月22日下午8:53:34
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.tuia.ssp.center.api.remote;

import java.util.List;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.AccountChangeDto;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqAccountChange;
import cn.com.duiba.wolf.dubbo.DubboResult;


/**
 * ClassName:RemoteAccountChangeService <br/>
 * Function: 账户信息. <br/>
 * Date:     2017年5月22日 下午8:53:34 <br/>
 * @author   guyan
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
@AdvancedFeignClient
public interface RemoteAccountChangeService {
    
    /**
     * 通过月账单id查询提现信息
     * 
     * @param cashId
     * @return
     * @since JDK 1.6
     */
    DubboResult<AccountChangeDto> getAccountChangeByCashId(Long cashId);

    /**
     * 通过cashId列表查询
     * @param cashIds
     * @return
     */
    List<AccountChangeDto> getAccountChangeByCashIds(List<Long> cashIds);
    /**
     * 通过账户Id查询账户表里面已经提现的信息
     *
     * @param mediaId
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<AccountChangeDto>> getAccountChangeListById(Long mediaId);

    /**
     * 通过媒体id列表查询提现信息
     * @param mediaIds 媒体id列表
     * @return
     */
    List<AccountChangeDto> getAccountChangeListByMediaIds(List<Long> mediaIds);

    /**
     * 查询媒体对应的余额
     * @param mediaId
     * @return
     */
    DubboResult<Long> getAccountBalance(Long mediaId);


    DubboResult<Integer> selectAccountChangeCount(ReqAccountChange req);

    DubboResult<List<AccountChangeDto>> getAccountChangeByPage(ReqAccountChange req);

    DubboResult<AccountChangeDto> getAccountChangeByMediaId(Long mediaId);

    DubboResult<List<AccountChangeDto>> getAccountChangeList(ReqAccountChange req);
}

==> ssp-center-api-1.1.59-20230412.084347-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteAccountChangeService.java <==
/**
 * Project Name:ssp-center-api
 * File Name:RemoteAccountChangeService.java
 * Package Name:cn.com.duiba.tuia.ssp.center.api.remote
 * Date:2017年5月22日下午8:53:34
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.tuia.ssp.center.api.remote;

import java.util.List;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.AccountChangeDto;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqAccountChange;
import cn.com.duiba.wolf.dubbo.DubboResult;


/**
 * ClassName:RemoteAccountChangeService <br/>
 * Function: 账户信息. <br/>
 * Date:     2017年5月22日 下午8:53:34 <br/>
 * @author   guyan
 * @version
 * @since    JDK 1.6
 * @see
 */
@AdvancedFeignClient
public interface RemoteAccountChangeService {

    /**
     * 通过月账单id查询提现信息
     *
     * @param cashId
     * @return
     * @since JDK 1.6
     */
    DubboResult<AccountChangeDto> getAccountChangeByCashId(Long cashId);

    /**
     * 通过cashId列表查询
     * @param cashIds
     * @return
     */
    List<AccountChangeDto> getAccountChangeByCashIds(List<Long> cashIds);
    /**
     * 通过账户Id查询账户表里面已经提现的信息
     *
     * @param mediaId
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<AccountChangeDto>> getAccountChangeListById(Long mediaId);

    /**
     * 通过媒体id列表查询提现信息
     * @param mediaIds 媒体id列表
     * @return
     */
    List<AccountChangeDto> getAccountChangeListByMediaIds(List<Long> mediaIds);

    /**
     * 查询媒体对应的余额
     * @param mediaId
     * @return
     */
    DubboResult<Long> getAccountBalance(Long mediaId);


    DubboResult<Integer> selectAccountChangeCount(ReqAccountChange req);

    DubboResult<List<AccountChangeDto>> getAccountChangeByPage(ReqAccountChange req);

    DubboResult<AccountChangeDto> getAccountChangeByMediaId(Long mediaId);

    DubboResult<List<AccountChangeDto>> getAccountChangeList(ReqAccountChange req);

    List<AccountChangeDto> selectListBySettlementId(List<Long> settlementIds);

    int deleteById(List<Long> ids);

    AccountChangeDto getPrevAccountChange(Long mediaId, Long ltId);
}
